Macros
Derive Macros
- Magic
Instantiate - Derive the
MagicInstantiatetrait for a struct or enum. Descriptions and validators can be added to fields using the#[magic(description = ...)]and#[magic(validator = ...)]attributes.
MagicInstantiate trait for a struct or enum.
Descriptions and validators can be added to fields using the #[magic(description = ...)] and #[magic(validator = ...)] attributes.